# xBRL-Forge

**xBRL-Forge** is an open-source tool designed to streamline the process of creating final XBRL (eXtensible Business Reporting Language) and iXBRL (Inline XBRL) reports by integrating data from multiple software applications. With xBRL-Forge, users can effortlessly generate XBRL taxonomies and compile comprehensive reports using a simple JSON structure for integration.

## Features, Docs & More

- [Check out the Readme & linked documentation](https://github.com/antonheitz/xBRL-Forge)

- [Check out the Release notes](https://github.com/antonheitz/xBRL-Forge/releases)

